==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AVirtualNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.AVirtualNonstaticInvoke

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e9e44369624cbc15 soot_jimple_parser_node_AVirtualNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVirtualinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$_init$038a29cadfba7585(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
extern struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$getVirtualinvoke$6b12d05a8b3b9b3a(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$setVirtualinvoke$a35f89e64f5a9a73(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$getVirtualinvoke$6b12d05a8b3b9b3a;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$setVirtualinvoke$a35f89e64f5a9a73;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
	struct _jc_soot_jimple_parser_node_TVirtualinvoke$object	*(*getVirtualinvoke$6b12d05a8b3b9b3a)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setVirtualinvoke$a35f89e64f5a9a73)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods	soot_jimple_parser_node_AVirtualNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TVirtualinvoke$object	*__5fvirtualinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs	soot_jimple_parser_node_AVirtualNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_AVirtualNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVirtualNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AVirtualNonstaticInvoke.h <==
// public final class soot.jimple.parser.node.AVirtualNonstaticInvoke

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e9e44369624cbc15 soot_jimple_parser_node_AVirtualNonstaticInvoke
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class d4ca50e4d96c30c8 soot_jimple_parser_node_PNonstaticInvoke

// header file dependencies
// @dep_header soot_jimple_parser_node_PNonstaticInvoke

#include "soot/jimple/parser/node/PNonstaticInvoke.h"

#ifndef _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_
#define _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_Switch$object;
struct _jc_soot_jimple_parser_node_TVirtualinvoke$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object;

typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable;
typedef const struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$_init$038a29cadfba7585(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$getVirtualinvoke$6b12d05a8b3b9b3a(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$setVirtualinvoke$a35f89e64f5a9a73(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$getVirtualinvoke$6b12d05a8b3b9b3a;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$setVirtualinvoke$a35f89e64f5a9a73;
extern _jc_method _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_TVirtualinvoke$object	*(*getVirtualinvoke$6b12d05a8b3b9b3a)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setVirtualinvoke$a35f89e64f5a9a73)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *, struct _jc_soot_jimple_parser_node_TVirtualinvoke$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PNonstaticInvoke$vmethods	soot_jimple_parser_node_PNonstaticInvoke;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vmethods	soot_jimple_parser_node_AVirtualNonstaticInvoke;
};

// Vtype
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs {
	struct _jc_soot_jimple_parser_node_TVirtualinvoke$object	*__5fvirtualinvoke__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs {
    _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_refs	soot_jimple_parser_node_AVirtualNonstaticInvoke;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_refs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_PNonstaticInvoke;
    _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$sub_nonrefs	soot_jimple_parser_node_AVirtualNonstaticInvoke;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$object {
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype	*vtype;
	_jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$vtype _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AVirtualNonstaticInvoke, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AVirtualNonstaticInvoke$class_object;

#endif	/* _JC_soot_jimple_parser_node_AVirtualNonstaticInvoke_H_ */
